@@ -3,7 +3,7 @@
 # Walk a directory, assembling a list of modules that need to be blacklisted
 # Then check which modules are loaded, and return those as a string
 
-. /etc/defaults/pmi
+. /etc/default/pmi
 
 if [ ! -d $BLACKLISTDIR ]; then
         echo "No such directory $BLACKLISTDIR, exiting" >&2
